@@ -282,7 +282,7 @@ class ThesaurusRolesMenuItem(JsMenuItem):
         return super(ThesaurusRolesMenuItem, self).render()
 
 
-class ThesaurusRolesEditForm(DialogEditForm, RolesEditForm):
+class ThesaurusRolesEditForm(RolesEditForm):
     """Thesaurus roles edit form"""
 
     interfaces = (IThesaurusRoles,)
